@@ -253,10 +253,20 @@ MOS_STATUS Av1BasicFeature::UpdateTrackedBufferParameters()
 
     m_trackedBuf->OnSizeChange();
 
-    // The MB code size here, it is from Arch's suggestion
-    const uint32_t numOfCU  = MOS_ROUNDUP_DIVIDE(m_frameWidth, 8) * MOS_ROUNDUP_DIVIDE(m_frameHeight, 8);
-
-    m_mbCodeSize = MOS_ALIGN_CEIL((numOfCU * CODECHAL_PAK_OBJ_EACH_CU), CODECHAL_PAGE_SIZE);
+    // Here to calculate the max coded data size needed for one frame according to LCU and CU partitions
+    //
+    // 1.LCU and CU num:
+    // LCU size is 64x64 so we can get the LCU num according to frame width and hight
+    // The restrict min CU size is 8x8 so we can get totally max 64 CUs per LCU
+    //
+    // 2.LCU and CU data size:
+    // LCU header size 5DW, CU size 8DW. And a DW size is 64bits(2 * sizeof(uint32_t))
+    // 
+    // 3.Calculate the max coded data size needed
+    //
+    // 4.Finally need to do page align for CL alignment at the end of the frame
+    uint32_t numOfLCU = MOS_ROUNDUP_DIVIDE(m_frameWidth, av1SuperBlockWidth) * MOS_ROUNDUP_DIVIDE(m_frameHeight, av1SuperBlockHeight);
+    m_mbCodeSize = MOS_ALIGN_CEIL(2 * sizeof(uint32_t) * (numOfLCU * 5 + numOfLCU * 64 * 8), CODECHAL_PAGE_SIZE);
     m_mvDataSize = 0;
 
     uint32_t downscaledWidthInMb4x =
@@ -335,8 +345,6 @@ MOS_STATUS Av1BasicFeature::UpdateFormat(void *params)
     ENCODE_CHK_NULL_RETURN(params);
     EncoderParams* encodeParams = (EncoderParams*)params;
 
-    PCODEC_VP9_ENCODE_SEQUENCE_PARAMS vp9SeqParams = nullptr;
-    PCODEC_HEVC_ENCODE_SEQUENCE_PARAMS hevcSeqParams = nullptr;
     PCODEC_AV1_ENCODE_SEQUENCE_PARAMS av1SeqParams = nullptr;
 
     av1SeqParams = static_cast<PCODEC_AV1_ENCODE_SEQUENCE_PARAMS>(encodeParams->pSeqParams);
@@ -354,6 +362,7 @@ MOS_STATUS Av1BasicFeature::UpdateFormat(void *params)
     {
     case Format_P010:
     case Format_R10G10B10A2:
+    case Format_B10G10R10A2:
         m_is10Bit  = true;
         m_bitDepth = 10;
         break;
@@ -457,16 +466,21 @@ MOS_STATUS Av1BasicFeature::GetTrackedBuffers()
 Av1StreamIn *Av1BasicFeature::GetStreamIn()
 {
     m_streamIn.Init(this, this->m_allocator, this->m_osInterface);
+    
     return &m_streamIn;
 }
 
+MediaFeatureManager *Av1BasicFeature::GetFeatureManager()
+{
+    return m_featureManager;
+}
+
 MOS_STATUS Av1BasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP_STATE& mmcState, uint32_t& compressionFormat) const
 {
     ENCODE_FUNC_CALL();
 
     ENCODE_CHK_NULL_RETURN(surface);
 
-#ifdef _MMC_SUPPORTED
     ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
@@ -477,7 +491,6 @@ MOS_STATUS Av1BasicFeature::GetSurfaceMmcInfo(PMOS_SURFACE surface, MOS_MEMCOMP_
     {
         mmcState = MOS_MEMCOMP_DISABLED;
     }
-#endif
 
     return MOS_STATUS_SUCCESS;
 }
@@ -775,8 +788,7 @@ MHW_SETPAR_DECL_SRC(VDENC_DS_REF_SURFACE_STATE, Av1BasicFeature)
 }
 
 MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
-{
-#ifdef _MMC_SUPPORTED    
+{    
     ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
@@ -790,7 +802,6 @@ MHW_SETPAR_DECL_SRC(VDENC_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
         params.mmcStateRaw          = MOS_MEMCOMP_DISABLED;
         params.compressionFormatRaw = GMM_FORMAT_INVALID;
     }
-#endif
 
     params.surfaceRaw                    = m_rawSurfaceToEnc;
     params.surfaceDsStage1               = m_8xDSSurface;
@@ -1064,8 +1075,7 @@ MHW_SETPAR_DECL_SRC(AVP_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
         BufferType::postCdefReconSurface, currRefList.ucScalingIdx);
     params.postCDEFpixelsBuffer = postCdefSurface;
 
-    // code from SetAvpPipeBufAddr
- #ifdef _MMC_SUPPORTED    
+    // code from SetAvpPipeBufAddr   
     ENCODE_CHK_NULL_RETURN(m_mmcState);
     if (m_mmcState->IsMmcEnabled())
     {
@@ -1079,7 +1089,6 @@ MHW_SETPAR_DECL_SRC(AVP_PIPE_BUF_ADDR_STATE, Av1BasicFeature)
         params.mmcStateRawSurf       = MOS_MEMCOMP_DISABLED;
         params.postCdefSurfMmcState  = MOS_MEMCOMP_DISABLED;
     }
-#endif
 
     params.decodedPic              = const_cast<PMOS_SURFACE>(&m_reconSurface);
     params.decodedPic->MmcState    = params.mmcStatePreDeblock;  // This is for MMC report only
