@@ -1,5 +1,5 @@
 /*
-* Copyright (c) 2022-2023, Intel Corporation
+* Copyright (c) 2022-2025, Intel Corporation
 *
 * Permission is hereby granted, free of charge, to any person obtaining a
 * copy of this software and associated documentation files (the "Software"),
@@ -182,21 +182,21 @@ MOS_STATUS MosUserSetting::InitMosCommonUserSetting(MediaUserSettingSharedPtr us
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_IP_ALIGNMENT_DECODE_TIMEOUT,
         MediaUserSetting::Group::Device,
-        20,
+        12,
         false);
 
     DeclareUserSettingKey(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_IP_ALIGNMENT_ENCODE_TIMEOUT,
         MediaUserSetting::Group::Device,
-        20,
+        12,
         false);
 
     DeclareUserSettingKey(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_IP_ALIGNMENT_VPP_TIMEOUT,
         MediaUserSetting::Group::Device,
-        20,
+        12,
         false);
 
     DeclareUserSettingKey(  //TRUE for Enabling Vebox Scalability. (Default FALSE: disabled")
@@ -245,6 +245,24 @@ MOS_STATUS MosUserSetting::InitMosCommonUserSetting(MediaUserSettingSharedPtr us
         true,
         USER_SETTING_CONFIG_PERF_PATH); //"Perf Profiler Multi Process Support."
 
+    DeclareUserSettingKey(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_ENABLE_MER_HEADER,
+        MediaUserSetting::Group::Device,
+        int32_t(0),
+        true,
+        true,
+        USER_SETTING_CONFIG_PERF_PATH);  //"Perf Profiler Merge by Header Support."
+
+    DeclareUserSettingKey(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_PARALLEL_EXEC,
+        MediaUserSetting::Group::Device,
+        false,
+        true,
+        true,
+        USER_SETTING_CONFIG_PERF_PATH); //"Perf Profiler Parallel Execution Support."
+
     DeclareUserSettingKey(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_PERF_PROFILER_OUTPUT_FILE_NAME,
@@ -425,6 +443,13 @@ MOS_STATUS MosUserSetting::InitMosCommonUserSetting(MediaUserSettingSharedPtr us
         1,
         true); //"Enable texture pooling in media driver."
 
+    DeclareUserSettingKey(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_MEDIA_NATIVE_FENCE_MODE,
+        MediaUserSetting::Group::Device,
+        1,
+        true);
+
     return MOS_STATUS_SUCCESS;
 }
 
@@ -491,7 +516,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_OS_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -512,7 +537,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_MHW_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -533,7 +558,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_CODEC_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -554,7 +579,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_VP_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -575,7 +600,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_CP_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -596,7 +621,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_DDI_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -617,7 +642,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_CM_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -638,7 +663,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_SCALABILITY_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -659,7 +684,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_MMC_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     DeclareUserSettingKey(
@@ -680,7 +705,7 @@ MOS_STATUS MosUserSetting::InitMosMessageUserSetting(MediaUserSettingSharedPtr u
         userSettingPtr,
         __MOS_USER_FEATURE_KEY_SUB_COMPONENT_MCPY_TAG,
         MediaUserSetting::Group::Device,
-        0,
+        uint64_t(0),
         true);
 
     return MOS_STATUS_SUCCESS;
@@ -910,6 +935,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         1,
         true); //"If enabled, media reset will be enabled."
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_FORCE_MEDIA_COMPRESSED_WRITE,
+        MediaUserSetting::Group::Device,
+        0,
+        true); //"If enabled, then to disable Unifined CMF."
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_FORCE_RESET_THRESHOLD,
@@ -987,13 +1019,6 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         "",
         true);
 
-    DeclareUserSettingKeyForDebug(
-        userSettingPtr,
-        __MEDIA_USER_FEATURE_VALUE_MEDIASOLO_TILE_Y_2_TILE_4_ADAPTER,
-        MediaUserSetting::Group::Device,
-        false,
-        true);
-
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_MEDIASOLO_ENABLE_MEM_TRACE,
@@ -1122,6 +1147,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         true,
         USER_SETTING_CONFIG_PERMANENT_PATH);//"If enabled, specify this is in pre-si simulation/emulation mode."
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_ENABLE_VDBOX_ID_REPORT,
+        MediaUserSetting::Group::Device,
+        0,
+        true); //"Enable Vdbox physical engine id report"
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_FORCE_VDBOX,
@@ -1136,6 +1168,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         0,
         true); //"Force the VEBox to be used. (Default 0: FORCE_VEBOX_NONE )"
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_USED_VDBOX_ID,
+        MediaUserSetting::Group::Device,
+        0,
+        true); //"Used Vdbox physical id. (Default 0: Not used, Each Hex symbol represents one VDBOX, e.g. bits[3:0] means VD0, bits[7:4] means VD1)"
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_FORCE_YFYS,
@@ -1339,6 +1378,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         0,
         true);
 
+    DeclareUserSettingKeyForDebug(  // VP PostComp Surface Copy Dump Enable
+        userSettingPtr,
+        __VPHAL_DBG_SURF_DUMP_POSTCOMP_RESOURCE_COPY,
+        MediaUserSetting::Group::Device,
+        0,
+        true);
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_SPLIT_SCREEN_DEMO_POSITION,
@@ -1359,7 +1405,14 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         MediaUserSetting::Group::Device,
         0,
         true); // "Enable NULL HW or not"
-
+#if (_DEBUG || _RELEASE_INTERNAL)
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_NULLHW_PROXY_REPEAT_COUNT,
+        MediaUserSetting::Group::Device,
+        0,
+        true);
+#endif
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_PLATFORM,
@@ -1381,6 +1434,13 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         39497,
         true); //"Device ID of mock device, default is 0x9A49"
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_VALUE_MOCKADAPTOR_PIPE,
+        MediaUserSetting::Group::Device,
+        0,
+        true);  //"The pipe number of mock device, default is 1"
+
     //Tile resource info report
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
@@ -1445,12 +1505,33 @@ MOS_STATUS MosUserSetting::InitUserSettingForDebug(MediaUserSettingSharedPtr use
         0,      // 0 is ignore. 1 blt, 2 render, 3 vebox, 4 bypass copy engine;
         true);  //"media copy force copy model."
 
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        __MEDIA_USER_FEATURE_ENABLE_VECOPY_SMALL_RESOLUTION,
+        MediaUserSetting::Group::Device,
+        0,
+        true);
+
     DeclareUserSettingKeyForDebug(
         userSettingPtr,
         "Bypass Evict",
         MediaUserSetting::Group::Device,
         0,
         true);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        "ForceTargetUsage",
+        MediaUserSetting::Group::Sequence,
+        uint32_t(0),
+        false);
+
+    DeclareUserSettingKeyForDebug(
+        userSettingPtr,
+        "ChromaPrefetchDisable",
+        MediaUserSetting::Group::Sequence,
+        uint32_t(0), // 0 chroma prefetch enabled, 1 chroma prefetch disabled ;
+        false);
     return MOS_STATUS_SUCCESS;
 }
 
