@@ -41,6 +41,10 @@ static const char *attrDumpBufferInBinary    = "DumpBufferInBinary";
 static const char *attrDumpToThreadFolder    = "DumpToThreadFolder";
 static const char *attrDumpCmdBufInBinary    = "DumpCmdBufInBinary";
 static const char *attrEnableFastDump        = "EnableFastDump";
+static const char *attrFastDumpAllowDataLoss = "FastDumpAllowDataLoss";
+static const char *attrFastDumpRenderCpyEn   = "FastDumpRenderCpyEn";
+static const char *attrFastDumpVeCpyEn       = "FastDumpVeCpyEn";
+static const char *attrFastDumpBltCpyEn      = "FastDumpBltCpyEn";
 
 //Codec Attr 
 static const char *attrPicParams               = "PicParams";
@@ -90,6 +94,7 @@ static const char *attrOverwriteCommands       = "OverwriteCommands";
 static const char *attrHuffmanTbl              = "HuffmanTbl";
 static const char *attrScanParams              = "ScanParams";
 static const char *attrDriverUltDump           = "DriverUltDump";
+static const char *attrGranularCRCDump         = "GranularCRCDump";
 
 static const char *attrDumpEncodePar          = "DumpEncodePar";
 static const char *attrForceCmdDumpLvl        = "ForceCmdDumpLvl";
